==> kdeutils_4.1.4.orig.tar.gz: kdeutils-4.1.4/okteta/core/tests/kpiecetablebytearraymodelkabstractbytearraymodeliftest.h <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KPIECETABLEBYTEARRAYMODELKABSTRACTBYTEARRAYMODELIFTEST_H
#define KPIECETABLEBYTEARRAYMODELKABSTRACTBYTEARRAYMODELIFTEST_H


// test
#include "kabstractbytearraymodeliftest.h"


class KPieceTableByteArrayModelKAbstractByteArrayModelIfTest : public KAbstractByteArrayModelIfTest
{
  protected: // KAbstractByteArrayModelIfTest API
    KHECore::KAbstractByteArrayModel *createByteArrayModel();
    void deleteByteArrayModel( KHECore::KAbstractByteArrayModel *byteArrayModel );
};

#endif

==> kdeutils_4.2.4.orig.tar.gz: kdeutils-4.2.4/okteta/core/tests/kpiecetablebytearraymodelkabstractbytearraymodeliftest.h <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KPIECETABLEBYTEARRAYMODELKABSTRACTBYTEARRAYMODELIFTEST_H
#define KPIECETABLEBYTEARRAYMODELKABSTRACTBYTEARRAYMODELIFTEST_H


// test
#include "kabstractbytearraymodeliftest.h"


class KPieceTableByteArrayModelKAbstractByteArrayModelIfTest : public KAbstractByteArrayModelIfTest
{
  protected: // KAbstractByteArrayModelIfTest API
    KHECore::AbstractByteArrayModel *createByteArrayModel();
    void deleteByteArrayModel( KHECore::AbstractByteArrayModel *byteArrayModel );
};

#endif
